.. include:: ../../README.rst
   :end-before: _documentation

.. toctree::
   :maxdepth: 1
   :hidden:

   install
   upgrade
   example
   modules-api
   other-impls
   contribute
   changelog
   code-of-conduct
